A test for testing the equality of the concentration parameters for ciruclar data: A test for testing the equality of the concentration parameter among g samples, where g >= 2 for ciruclar data
Description
A test for testing the equality of the concentration parameter among g samples, where g >= 2 for ciruclar data. It is a tangential approach.
Usage
tang.conc(u, ina, rads = FALSE)
Value
This is an "htest"class object. Thus it returns a list including:
statistic
The test statistic value.
parameter
The degrees of freedom of the test.
p.value
The p-value of the test.
alternative
A character with the alternative hypothesis.
method
A character with the test used.
data.name
A character vector with two elements.
Arguments
u
A numeric vector containing the values of all samples.
ina
A numerical variable or factor indicating the groups of each value.
rads
If the data are in radians this should be TRUE and FALSE otherwise.
Mardia, K. V. and Jupp, P. E. (2000). Directional statistics. Chicester: John Wiley & Sons.
Fisher, N. I. (1995). Statistical analysis of circular data. Cambridge University Press.