MLE of the Wood bimodal distribution on the sphere: MLE of the Wood bimodal distribution on the sphere
Description
It estimates the parameters of the Wood bimodal distribution.
Usage
wood.mle(y)
Value
A list including:
info
A 5 x 3 matrix containing the 5 parameters, \(\gamma\), \(\delta\), \(\alpha\), \(\beta\) and \(\kappa\) along with their corresponding 95% confidence intervals all expressed in degrees.
modes
The two axis of the modes of the distribution expressed in degrees.
unitvectors
A 3 x 3 matrix with the 3 unit vectors associated with the \(\gamma\) and \(\delta\) parameters.
loglik
The value of the log-likelihood.
Arguments
y
A matrix containing two columns. The first one is the latitude and the second is the longitude, both expressed in degrees.
The Wood distribution is fitted to some data and its parameters are estimated. It is a bimodal distribution which contains 5 parameters, just like the Kent distribution.
References
Wood A.T.A. (1982). A bimodal distribution on the sphere.
Journal of the Royal Statistical Society, Series C, 31(1): 52--58.