View source: R/gcpc.means.test.R
| Two sample location test for circular data under the GCPC distribution | R Documentation |
Two sample location test for circular data under the GCPC distribution.
gcpc.means.test(u1, u2, rads = FALSE)
u1 |
A numeric vector containing circular data for the first sample. |
u2 |
A numeric vector containing circular data for the second sample. |
rads |
If the data are in radians, this should be TRUE and FALSE otherwise. |
The log-likelihood ratio test compares the location parameter of two independent samples, assuming that both samples are drawn from populations that follow the GCPC distribution.
This is an "htest"class object. Thus it returns a list including:
statistic |
The test statistic value. |
parameter |
The degree(s) of freedom of the test. |
p.value |
The p-value of the test. |
alternative |
A character with the alternative hypothesis. |
method |
A character with the test used. |
data.name |
A character vector with two elements. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Mardia, K. V. and Jupp, P. E. (2000). Directional statistics. Chicester: John Wiley & Sons.
Rumcheva P. and Presnell B. (2017). An improved test of equality of mean directions for the Langevin-von Mises-Fisher distribution. Australian & New Zealand Journal of Statistics, 59(1): 119–135.
Alzeley O. and Tsagris M. (2026). On the generalized circular projected Cauchy distribution. https://arxiv.org/abs/2603.04030.
hcf.circaov, spcauchy2test
u1 <- rgcpc(50, omega = 2, g = 5, rho = 0.5, rads = TRUE)
u2 <- rgcpc(50, omega = 2, g = 10, rho = 5, rads = TRUE)
gcpc.means.test(u1, u2, rads = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.